@@ -52,7 +52,7 @@ def check_block_sanity(raw_bytes):
     try:
         if block_timestamp + kasten.get_metadata()['expire'] >= timestamp:
             raise BlockExpired()
-    except (IndexError, TypeError):
+    except (IndexError, TypeError, KeyError):
         pass
 
 
